==> haskell-hackage-db-2.1.3-183.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-db.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-2ZUTFAVxVFb5Trgi7AH796
key:                  hackage-db-2.1.3-2ZUTFAVxVFb5Trgi7AH796
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  e3c446e9f1d58cf706a17e68a352b646
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-2ZUTFAVxVFb5Trgi7AH796
depends:
    Cabal-3.10.3.0 aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    tar-0.5.1.1-D8lXj4v6hLL5fJ348I6jpg time-1.12.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-db-2.1.3-184-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-db.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-IJaRrSAHDS6HLbmhmQjFAK
key:                  hackage-db-2.1.3-IJaRrSAHDS6HLbmhmQjFAK
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  624289acc61eeb19fd12670142243a0a
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-IJaRrSAHDS6HLbmhmQjFAK
depends:
    Cabal-3.10.3.0 aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    tar-0.5.1.1-4iAxOGYV1lQH2RPEJbrO6a time-1.12.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
